<?php

namespace Drupal\site_audit_report_entity\Plugin\SiteAuditCheck;

use DevShop\Component\Common\GitRepositoryAwareTrait;
use Drupal\site_audit\Plugin\SiteAuditCheckBase;

/**
 * Provides the CronLast Check.
 *
 * @SiteAuditCheck(
 *  id = "codebase_git_ref",
 *  name = @Translation("Git Reference"),
 *  description = @Translation("Current checked out git reference of this site."),
 *  report = "codebase",
 *  weight = -1,
 * )
 */
class CodebaseGitRef extends SiteAuditCheckBase {

  use GitRepositoryAwareTrait;

  /**
   * {@inheritdoc}.
   */
  public function getResultInfo() {
    return $this->registry->git_ref;
  }

  /**
   * {@inheritdoc}.
   */
  public function getResultPass() {}

  /**
   * {@inheritdoc}.
   */
  public function getResultWarn() {
    return $this->t('Empty, or unable to determine git reference due to a permission error.');
  }

  /**
   * {@inheritdoc}.
   */
  public function getResultFail() {}

  /**
   * {@inheritdoc}.
   */
  public function getAction() {}

  /**
   * {@inheritdoc}.
   */
  public function calculateScore() {
    try {
      $this->registry->git_ref = $this->getRepository()->getCurrentBranch();
      if (!$this->registry->git_ref) {
        return SiteAuditCheckBase::AUDIT_CHECK_SCORE_WARN;
      }
      return SiteAuditCheckBase::AUDIT_CHECK_SCORE_INFO;
    }
    catch (\Exception $e) {
      return SiteAuditCheckBase::AUDIT_CHECK_SCORE_WARN;
    }
  }

}
